api.system.components.runtime.v1.instance package — Argus-Toolbelt 1.0 documentation

# api.system.components.runtime.v1.instance package

## Submodules

## api.system.components.runtime.v1.instance.instance_install module

Autogenerated API

`api.system.components.runtime.v1.instance.instance_install.` `get_container_performance`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch performance details from specified component (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of instance to fetch performance data from
  Raises: | AuthenticationFailedException – on 401 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {}

`api.system.components.runtime.v1.instance.instance_install.` `get_instance_status`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch status for specified component (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of host to fetch status for
  Raises: | AuthenticationFailedException – on 401 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“installedInstanceRevision”: 2, “installedTemplateRevision”: 864, “templateID”: 694, “instanceID”: 50, “templateName”: “Inside wide hold reduce.”, “monitored”: true, “inDowntime”: true}

`api.system.components.runtime.v1.instance.instance_install.` `install`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Install configuration for instance (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of instance to install
  Raises: | AuthenticationFailedException – on 401 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“exact”: true, “identifiers”: {“additionalProperties”: “Across side behavior.”}}

`api.system.components.runtime.v1.instance.instance_install.` `reboot`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Reboot runtime instance (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of instance to reboot
  Raises: | AuthenticationFailedException – on 401 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 874, “limit”: 53, “responseCode”: 200, “count”: 323, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Clearly enjoy natural dark structure.”, “messageTemplate”: “Together against south bar yeah.”, “field”: “Yes without lot gas discover support political.”, “parameter”: {}, “timestamp”: 1287615532}], “currentPage”: 177, “size”: 637}

`api.system.components.runtime.v1.instance.instance_install.` `refresh_instance_status`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Request specified component to immediately refresh status (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of component to request update from
  Raises: | AuthenticationFailedException – on 401 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {}

`api.system.components.runtime.v1.instance.instance_install.` `start`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Initiate runtime instance (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of instance to start
  Raises: | AuthenticationFailedException – on 401 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 334, “limit”: 819, “responseCode”: 200, “count”: 934, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Direction you democratic young edge get.”, “messageTemplate”: “Far apply own try give.”, “field”: “Difficult agency modern represent power you tough.”, “parameter”: {}, “timestamp”: 1422204457}], “currentPage”: 125, “size”: 611}

`api.system.components.runtime.v1.instance.instance_install.` `stop`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Shutdown runtime instance (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of instance to stop
  Raises: | AuthenticationFailedException – on 401 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 171, “limit”: 783, “responseCode”: 200, “count”: 907, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Go feeling financial leave.”, “messageTemplate”: “Respond relationship minute painting executive seat.”, “field”: “Style save mention out determine.”, “parameter”: {}, “timestamp”: 1083095895}], “currentPage”: 671, “size”: 157}

`api.system.components.runtime.v1.instance.instance_install.` `uninstall`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Uninstall configuration for instance (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of instance to uninstall
  Raises: | AuthenticationFailedException – on 401 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“exact”: false, “identifiers”: {“additionalProperties”: “Present next card since soon happen resource.”}}

## Module contents